@@ -1,6 +1,6 @@
 package SVN::Log::Index;
 
-# $Id: Index.pm 130 2004-05-29 22:56:28Z rooneg $
+# $Id: Index.pm 208 2004-06-14 11:00:55Z rooneg $
 
 use strict;
 
@@ -11,7 +11,9 @@ use Plucene::Analysis::SimpleAnalyzer;
 use Plucene::Search::IndexSearcher;
 use Plucene::QueryParser;
 
-our $VERSION = '0.22';
+use SVN::Log;
+
+our $VERSION = '0.30';
 
 =head1 NAME
 
@@ -68,7 +70,7 @@ sub _open_writer {
 }
 
 sub _handle_log {
-  my ($self, $paths, $rev, $author, $date, $msg, $pool) = @_;
+  my ($self, $paths, $rev, $author, $date, $msg) = @_;
 
   my $doc = Plucene::Document->new ();
 
@@ -113,89 +115,6 @@ range of revisions from $start_rev to $end_rev will be added.
 =cut
 
 sub add {
-  # we only pull this in here so that the search portions of this module 
-  # can be used in environments where the svn libs can't be linked against.
-  #
-  # this can happen, for example, when apache and mod_perl2 are linked 
-  # against different versions of the APR libraries than subversion is.
-  #
-  # not that i happen to have a system like that or anything...
-  eval {
-    require SVN::Core;
-    require SVN::Ra;
-  };
-
-  if ($@) {
-    # oops, we don't have the SVN perl libs installed, so instead we need
-    # to fall back to using the command line client the old fashioned way
-    *_do_log = *_do_log_commandline;
-  } else {
-    *_do_log = *_do_log_bindings;
-  }
-
-  # alias add to _add, so we only do the require the first time through.
-  *add = *_add;
-
-  # let's try this again...
-  add (@_);
-}
-
-sub _do_log_bindings {
-  my ($self, $repos, $start_rev, $end_rev) = @_;
-
-  my $r = SVN::Ra->new (url => $repos) or die "error opening RA layer: $!";
-
-  $r->get_log ([''], $start_rev, $end_rev, 1, 0,
-               sub { $self->_handle_log (@_); });
-}
-
-sub _do_log_commandline {
-  my ($self, $repos, $start_rev, $end_rev) = @_;
-
-  open my $log, "svn log -v -r $start_rev:$end_rev $repos|"
-    or die "couldn't open pipe to svn process: $!";
-
-  my ($paths, $rev, $author, $date, $msg);
-
-  my $state = 'start';
-
-  my $seprule  = qr/^-{72}$/;
-  my $headrule = qr/r(\d+) \| (\w+) \| (\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2})/;
-
-  # XXX i'm sure this can be made much much cleaner...
-  while (<$log>) {
-    if ($state eq 'start' or $state eq 'message' and m/$seprule/) {
-      if ($state eq 'start') {
-        $state = 'head';
-      } elsif ($state eq 'message') {
-        $state = 'start';
-        $self->_handle_log($paths, $rev, $author, $date, $msg);
-      }
-    } elsif ($state eq 'head' and m/$headrule/) {
-      $rev = $1;
-      $author = $2;
-      $date = $3;
-      $paths = {};
-      $msg = "";
-
-      $state = 'paths';
-    } elsif ($state eq 'paths') {
-      unless (m/^Changed paths:$/) {
-        if (m/^$/) {
-          $state = 'message';
-        } else {
-          if (m/^\s+\w+ (.+)$/) {
-            $paths->{$1} = 1; # we only care about the filename anyway...
-          }
-        }
-      }
-    } elsif ($state eq 'message') {
-      $msg .= $_;
-    }
-  }
-}
-
-sub _add {
   my ($self, $repos, $start_rev, $end_rev) = @_;
 
   $end_rev = $start_rev unless defined $end_rev;
@@ -210,7 +129,10 @@ sub _add {
     $repos = "file://$repos";
   }
 
-  $self->_do_log ($repos, $start_rev, $end_rev);
+  SVN::Log::retrieve ({ repository => $repos,
+                        start => $start_rev,
+                        end => $end_rev,
+                        callback => sub { $self->_handle_log(@_); } });
 
   undef $self->{writer};
   undef $self->{url};
